@@ -24,6 +24,12 @@ PATH: Final = 'path'
 # 'path' from iterables
 # 'default'
 
+# Regexp
+REGEXP: Final[str] = 'regexp'
+SEARCH: Final[str] = 'search'
+GROUP: Final[str] = 'group'
+DEFAULT_GROUP: Final[int] = 0
+
 # IF STATEMENT
 CONDITION: Final = 'condition'
 IS: Final = 'is'
